==> texlive-bin_2013.20130729.30972.orig.tar.xz: texlive-bin-2013.20130729.30972/texk/dvisvgm/dvisvgm-1.2.2/src/DvisvgmSpecialHandler.h <==
/*************************************************************************
** DvisvgmSpecialHandler.h                                              **
**                                                                      **
** This file is part of dvisvgm -- the DVI to SVG converter             **
** Copyright (C) 2005-2013 Martin Gieseking <martin.gieseking@uos.de>   **
**                                                                      **
** This program is free software; you can redistribute it and/or        **
** modify it under the terms of the GNU General Public License as       **
** published by the Free Software Foundation; either version 3 of       **
** the License, or (at your option) any later version.                  **
**                                                                      **
** This program is distributed in the hope that it will be useful, but  **
** WITHOUT ANY WARRANTY; without even the implied warranty of           **
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the         **
** GNU General Public License for more details.                         **
**                                                                      **
** You should have received a copy of the GNU General Public License    **
** along with this program; if not, see <http://www.gnu.org/licenses/>. **
*************************************************************************/

#ifndef DVISVGMSPECIALHANDLER_H
#define DVISVGMSPECIALHANDLER_H

#include "SpecialHandler.h"

class DvisvgmSpecialHandler : public SpecialHandler
{
   public:
		const char* name () const   {return "dvisvgm";}
		const char* info () const   {return "special set for embedding raw SVG snippets";}
		const char** prefixes () const;
		bool process (const char *prefix, std::istream &in, SpecialActions *actions);
};

#endif

==> texlive-bin_2014.20140528.34243.orig.tar.xz: texlive-bin-2014.20140528.34243/texk/dvisvgm/dvisvgm-1.6/src/DvisvgmSpecialHandler.h <==
/*************************************************************************
** DvisvgmSpecialHandler.h                                              **
**                                                                      **
** This file is part of dvisvgm -- the DVI to SVG converter             **
** Copyright (C) 2005-2014 Martin Gieseking <martin.gieseking@uos.de>   **
**                                                                      **
** This program is free software; you can redistribute it and/or        **
** modify it under the terms of the GNU General Public License as       **
** published by the Free Software Foundation; either version 3 of       **
** the License, or (at your option) any later version.                  **
**                                                                      **
** This program is distributed in the hope that it will be useful, but  **
** WITHOUT ANY WARRANTY; without even the implied warranty of           **
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the         **
** GNU General Public License for more details.                         **
**                                                                      **
** You should have received a copy of the GNU General Public License    **
** along with this program; if not, see <http://www.gnu.org/licenses/>. **
*************************************************************************/

#ifndef DVISVGM_DVISVGMSPECIALHANDLER_H
#define DVISVGM_DVISVGMSPECIALHANDLER_H

#include "SpecialHandler.h"

class DvisvgmSpecialHandler : public SpecialHandler
{
   public:
		const char* name () const   {return "dvisvgm";}
		const char* info () const   {return "special set for embedding raw SVG snippets";}
		const char** prefixes () const;
		bool process (const char *prefix, std::istream &is, SpecialActions *actions);
};

#endif
